@@ -6,17 +6,6 @@ from typing import Any, List
 from urllib.parse import urlparse
 from dbutils import steady_db
 
-import warnings
-import logging
-import time
-
-
-# warnings.filterwarnings('error', category=pymysql.err.Warning)
-# # use logging module for easy debug
-# logging.basicConfig(format='%(asctime)s %(levelname)8s: %(message)s', datefmt='%m-%d %H:%M:%S')
-# logger = logging.getLogger(__name__)
-# logger.setLevel('WARNING')
-
 
 def convert_qmark_query_to_adapter_style(query, params, to_format="format"):
     """
@@ -36,6 +25,7 @@ def convert_qmark_query_to_adapter_style(query, params, to_format="format"):
     _sqlparams = sqlparams.SQLParams(from_format, to_format)
     return _sqlparams.format(query, params)
 
+
 class Adapter(object):
     """
     Base Adapter class
@@ -45,6 +35,9 @@ class Adapter(object):
     # Holds the db connection
     db = None
 
+    # The engine: sqlite, mysql for (mysql|mariadb), postgresql 
+    engine = None
+
     def execute(self, query: str, params: Any = None) -> Any:
         """
         Executes a query
@@ -128,7 +121,7 @@ class Adapter(object):
         Returns:
             int
         """
-        return self.fetchone("SELECT count(*) FROM %s;" % table)[0]
+        return self.fetchone("SELECT COUNT(*) AS count FROM %s" % table)["count"]
 
     def fetchone(self, query: str, params: Any = {}) -> Any:
         """
@@ -199,9 +192,9 @@ class SQLiteAdapter(Adapter):
     SQLiteAdapter("sqlite:///file.db") - file
     """
 
-    db = None
     _columns = []
     _indexes = []
+    engine = "sqlite"
 
     def __init__(self, file: str = ":memory:"):
         if file in ["sqlite://"]:
@@ -288,11 +281,24 @@ class SQLiteAdapter(Adapter):
 class MySQLAdapter(Adapter):
     """
     MySQL Adapter 
+
+    MySQLAdapter("mysql://user:password@host:port/dbname")
     """
+    
+    engine = "mysql"
+
+    # Caching columns and indexes
+    _columns = []
+    _indexes = []
+
+    type_converter = {
+        "boolean": "TINYINT(1)",
+        "text": "VARCHAR"
+    }
+
     def __init__(self, dsn: str, autocommit=True):
         _ = urlparse(dsn)
         dbname = _.path.strip("/") or None
-        #connection = pymysql.connect(host=_.hostname,
         config = {
             "host": _.hostname,
             "user": _.username,
@@ -301,8 +307,7 @@ class MySQLAdapter(Adapter):
             "port": _.port,
             "autocommit": autocommit
         }
-        #db = steady_db.connect(creator = pymysql, **config)
-        self.db = pymysql.connect(**config)
+        self.db = steady_db.connect(creator = pymysql, **config)
 
     def execute(self, query, params={}):
         with self.db.cursor() as cursor:
